@@ -43,28 +43,3 @@ sub violates {
 
 1;
 
-__END__
-
-=pod
-
-=head1 NAME
-
-Perl::Critic::Policy::OTRS::ProhibitPushISA - Do not use "push @ISA, ..."
-
-=head1 VERSION
-
-version 0.05
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2013 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
