@@ -32,28 +32,3 @@ sub violates {
 
 1;
 
-__END__
-
-=pod
-
-=head1 NAME
-
-Perl::Critic::Policy::OTRS::ProhibitRmtree - Do not use File::Path's rmtree
-
-=head1 VERSION
-
-version 0.05
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2013 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
